standard

package
v0.0.0-...-e07cf5f Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 11, 2026 License: MIT Imports: 10 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Extractor

type Extractor struct {
	// contains filtered or unexported fields
}

Extractor handles file extraction from standard OCI layers

func NewExtractor

func NewExtractor(layer v1.Layer) *Extractor

NewExtractor creates a new standard layer extractor

func (*Extractor) ExtractFile

func (e *Extractor) ExtractFile(ctx context.Context, targetPath string, outputPath string) error

ExtractFile extracts a specific file from a standard OCI layer This downloads and decompresses the entire layer, which is less efficient than eStargz or SOCI, but works for any OCI layer

func (*Extractor) ListFiles

func (e *Extractor) ListFiles(ctx context.Context) ([]string, error)

ListFiles lists all files in a standard OCI layer

Jump to