Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Extractor ¶
type Extractor struct {
// contains filtered or unexported fields
}
Extractor handles file extraction from standard OCI layers
func NewExtractor ¶
NewExtractor creates a new standard layer extractor
func (*Extractor) ExtractFile ¶
ExtractFile extracts a specific file from a standard OCI layer This downloads and decompresses the entire layer, which is less efficient than eStargz or SOCI, but works for any OCI layer
Click to show internal directories.
Click to hide internal directories.